pub struct ExperimentRecord { /* private fields */ }Expand description
Experiment Record represents a tracked experiment.
This is the root entity in the experiment tracking schema. Each experiment can have multiple runs.
Implementations
Sourceimpl ExperimentRecord
impl ExperimentRecord
Sourcepub fn builder(
experiment_id: impl Into<String>,
name: impl Into<String>,
) -> ExperimentRecordBuilder
pub fn builder( experiment_id: impl Into<String>, name: impl Into<String>, ) -> ExperimentRecordBuilder
Create a builder for constructing an experiment record with optional fields.
Sourcepub fn experiment_id(&self) -> &str
pub fn experiment_id(&self) -> &str
Get the experiment ID.
Sourcepub const fn created_at(&self) -> DateTime<Utc>
pub const fn created_at(&self) -> DateTime<Utc>
Get the creation timestamp.